registered_target_plan_overlay

Function registered_target_plan_overlay 

pub fn registered_target_plan_overlay(
    spell_id: u32,
    effect_index: u8,
) -> Result<Option<&'static TargetPlanOverlay>, TargetPlanError>
Find the unique content overlay for a spell effect.

Errors

Returns an error when multiple overlays register the same spell effect.